@@ -162,7 +162,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_getDTD, 5),
 	ENTRY(RS_XML_libxmlVersion, 0),
 	ENTRY(RS_XML_Parse, 17),
-	ENTRY(RS_XML_ParseTree, 20),
+	ENTRY(RS_XML_ParseTree, 21),
 	ENTRY(R_newXMLDtd, 5),
 	ENTRY(R_newXMLDoc, 3),
 	ENTRY(R_newXMLNode, 6),
@@ -228,7 +228,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_xmlNodeName, 1),
 	ENTRY(RS_XML_xmlNodeNamespace, 1),
 	ENTRY(RS_XML_xmlNodeAttributes, 3),
-	ENTRY(RS_XML_xmlNodeChildrenReferences, 3),
+	// ENTRY(RS_XML_xmlNodeChildrenReferences, 3), // duplicate
 	ENTRY(R_xmlNodeValue, 3),
 	ENTRY(R_setXMLInternalTextNode_value, 2),
 	ENTRY(RS_XML_xmlNodeParent, 2),
@@ -365,4 +365,21 @@ R_lookString(SEXP rstr)
 }
 
 
+#if 0
+#include <libxml/uri.h>
+SEXP
+R_relativeURL(SEXP r_url, SEXP r_base)
+{
+    xmlChar *url, *base;
+    const xmlChar *ans;
+    SEXP rans;
+    url = CHAR_DEREF(STRING_ELT(r_url, 0));
+    base = CHAR_DEREF(STRING_ELT(r_base, 0));
+    ans = xmlBuildRelativeURI(url, base);
+    rans = ScalarString(COPY_TO_USER_STRING(ans));
+    xmlFree(ans);
+    return(rans);
+}
+#endif
+
 
