@@ -227,7 +227,7 @@ SEXP CreateCharSexpWithEncoding(const xmlChar *encoding, const xmlChar *str);
 
 #ifdef R_USE_XML_ENCODING
 #undef COPY_TO_USER_STRING
-#warning "Redefining COPY_TO_USER_STRING to use encoding from XML parser"
+//#warning "Redefining COPY_TO_USER_STRING to use encoding from XML parser"
 /*
 #define COPY_TO_USER_STRING(x)  CreateCharSexpWithEncoding(encoding, CHAR_TO_XMLCHAR (x))
 */
